@@ -4,4 +4,4 @@
 
 from dtrange import *
 from scisel import *
-from sciproc import *
+from scimulti import *
