@@ -11,7 +11,7 @@ from dtrange import *
 # - we expect that the data at the asked sample time (outcoords) exists in the original sample (coords). If not, a nan will be produced.
 def cosel(coords = None, outcoords = None):
     steps = len(outcoords)
-    selout = list(None,steps)
+    selout = repeat(None,steps)
     idx = 0
     outidx = 0
     for datetime in coords:
